@@ -272,7 +272,7 @@ class CloudFrontToApiGatewayProps:
         :summary: The properties for the CloudFrontToApiGateway Construct
         '''
         if isinstance(cloud_front_logging_bucket_props, dict):
-            cloud_front_logging_bucket_props = BucketProps(**cloud_front_logging_bucket_props)
+            cloud_front_logging_bucket_props = aws_cdk.aws_s3.BucketProps(**cloud_front_logging_bucket_props)
         if __debug__:
             type_hints = typing.get_type_hints(CloudFrontToApiGatewayProps.__init__)
             check_type(argname="argument existing_api_gateway_obj", value=existing_api_gateway_obj, expected_type=type_hints["existing_api_gateway_obj"])
